@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Flask Quorum
-# Copyright (c) 2008-2021 Hive Solutions Lda.
+# Copyright (c) 2008-2022 Hive Solutions Lda.
 #
 # This file is part of Hive Flask Quorum.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2022 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -524,6 +524,10 @@ def load(
     )
     app._locale_d = locales[0]
 
+    # takes a snapshot of the current timestamp as it's
+    # considered to be the start time of the application
+    app.start_time = time.time()
+
     # sets a series of conditional based attributes in both
     # the associated modules and the base app object (as expected)
     if redis_url: redisdb.url = redis_url
