@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Flask Quorum
-# Copyright (c) 2008-2021 Hive Solutions Lda.
+# Copyright (c) 2008-2022 Hive Solutions Lda.
 #
 # This file is part of Hive Flask Quorum.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2022 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -97,6 +97,20 @@ def xlsx_to_map(file_path, keys = (), types = (), ignore_header = True):
     return items
 
 def xlsx_raw(cell_s):
+    """
+    Sanitizes the string value for the cell, taking into
+    consideration integers and strings as different data types,
+    the returning value is always a string.
+
+    :type cell_s: Cell
+    :param cell_S: The cell base value, that is going to be
+    tested for data type and from which a sanitized string
+    value should be returned.
+    :rtype: String
+    :return: The sanitized string value from the cell value
+    ready to be used.
+    """
+
     is_str = cell_s.ctype == xlrd.XL_CELL_TEXT
     if is_str: return cell_s.value
     try: is_int = cell_s.value == int(cell_s.value)
