@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Flask Quorum
-# Copyright (c) 2008-2021 Hive Solutions Lda.
+# Copyright (c) 2008-2022 Hive Solutions Lda.
 #
 # This file is part of Hive Flask Quorum.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2022 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -287,6 +287,51 @@ def delete_json(
         if retries == 0:
             raise exceptions.HTTPError("Data retrieval not possible")
 
+def patch_json(
+    url,
+    headers = None,
+    handle = None,
+    silent = None,
+    redirect = None,
+    timeout = None,
+    auth_callback = None,
+    **kwargs
+):
+    # starts the variable holding the number of
+    # retrieves to be used
+    retries = 5
+
+    while True:
+        try:
+            return _patch_json(
+                url,
+                headers = headers,
+                handle = handle,
+                silent = silent,
+                redirect = redirect,
+                timeout = timeout,
+                **kwargs
+            )
+        except legacy.HTTPError as error:
+            if error.code in AUTH_ERRORS and auth_callback:
+                _try_auth(auth_callback, kwargs)
+            else:
+                data_r = error.read()
+                data_r = legacy.str(data_r, encoding = "utf-8")
+                data_s = json.loads(data_r)
+                raise exceptions.JSONError(data_s)
+
+        # decrements the number of retries and checks if the
+        # number of retries has reached the limit
+        retries -= 1
+        if retries == 0:
+            raise exceptions.HTTPError("Data retrieval not possible")
+
+def basic_auth(username, password = None):
+    if not password: password = username
+    authorization = _authorization(username, password)
+    return "Basic %s" % authorization
+
 def _try_auth(auth_callback, params, headers = None):
     if not auth_callback: raise
     if headers == None: headers = dict()
@@ -396,6 +441,26 @@ def _delete_json(
         **kwargs
     )
 
+def _patch_json(
+    url,
+    headers = None,
+    handle = None,
+    silent = None,
+    redirect = None,
+    timeout = None,
+    **kwargs
+):
+    return _method_empty(
+        "PATCH",
+        url,
+        headers = headers,
+        handle = handle,
+        silent = silent,
+        redirect = redirect,
+        timeout = timeout,
+        **kwargs
+    )
+
 def _method_empty(
     name,
     url,
@@ -619,9 +684,7 @@ def _parse_url(url):
     url = parse.scheme + "://" + parse.hostname + ":" + str(port) + parse.path
     if port in (80, 443): host = parse.hostname
     else: host = parse.hostname + ":" + str(port)
-    username = parse.username
-    password = parse.password
-    authorization = _authorization(username, password)
+    authorization = _authorization(parse.username, parse.password)
     params = _params(parse.query)
     return (url, scheme, host, authorization, params)
 
