@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Flask Quorum
-# Copyright (c) 2008-2021 Hive Solutions Lda.
+# Copyright (c) 2008-2022 Hive Solutions Lda.
 #
 # This file is part of Hive Flask Quorum.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2022 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -118,6 +118,27 @@ class ModelTest(quorum.TestCase):
         result = mock.Person.count()
         self.assertEqual(result, 1)
 
+    @quorum.secured
+    def test_count_find(self):
+        adapter = quorum.get_adapter()
+        if not adapter.name in ("mongo",):
+            if not hasattr(self, "skipTest"): return
+            self.skipTest("Adapter is not supported")
+
+        result = mock.Person.count()
+        self.assertEqual(result, 0)
+
+        person = mock.Person()
+        person.age = 1
+        person.name = "Name"
+        person.save()
+
+        result = mock.Person.count(**dict(find_d = ["name:eq:Name"]))
+        self.assertEqual(result, 1)
+
+        result = mock.Person.count(**dict(find_d = ["name:eq:OtherName"]))
+        self.assertEqual(result, 0)
+
     @quorum.secured
     def test_delete(self):
         result = mock.Person.count()
